@@ -1,5 +1,5 @@
 package Lingua::EN::Pseudolocalize;
-use strict; use warnings;
+use strict; use warnings; use 5.008;
 use Sub::Exporter::Simple qw/convert deconvert/;
 use charnames ':full';
 
@@ -56,7 +56,7 @@ Lingua::EN::Pseudolocalize - Test Unicode support by pretending to speak a diffe
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
